
Changelog
=========

0.13.0
------

**Breaking changes**

* Change to OpenAPI specifications
* Remove python 3.5 support
* Remove caching of parameters between calls
* Method parameters are typed checked to the OpenAPI schemas

0.1.0 (?)
------------------

* First release on PyPI.
